[pisa-src] r1449 - trunk/pairing/libconfig_wrapper.c

  • From: Thomas Jansen <mithi@xxxxxxxxx>
  • To: pisa-src@xxxxxxxxxxxxx
  • Date: Fri, 30 Oct 2009 11:58:40 +0100

Author: tjansen
Date: Fri Oct 30 11:58:40 2009
New Revision: 1449

Log:
Fix -Wshadow warning:

libconfig_wrapper.c: In function ‘get_config_setting’:
libconfig_wrapper.c:89: warning: declaration of ‘strlen’ shadows a global 
declaration
/usr/include/string.h:397: warning: shadowed declaration is here

Modified:
   trunk/pairing/libconfig_wrapper.c

Modified: trunk/pairing/libconfig_wrapper.c
==============================================================================
--- trunk/pairing/libconfig_wrapper.c   Fri Oct 30 11:56:37 2009        (r1448)
+++ trunk/pairing/libconfig_wrapper.c   Fri Oct 30 11:58:40 2009        (r1449)
@@ -81,12 +81,12 @@
  *  @param path Pointer to a string containing the path (libconfig style)
  *  @param type Type of data desired (e.g. CONFIG_TYPE_INT); use defined 
values from libconfig
  *  @param return_val Pointer to the variable where the information should be 
stored
  *  @param strlen Length of the string (if looking up a string).
  *
  *  @return 1 on success; 0 on failure
  *
  */
-int get_config_setting(const char *filename, const char *path, int type, void 
*return_val, int strlen)
+int get_config_setting(const char *filename, const char *path, int type, void 
*return_val, int len)
 {
        config_t cfg;
        config_setting_t *root;
@@ -124,7 +124,7 @@
                                DEBUG("Problem getting setting at path \'%s\' 
from file \'%s\'.", path, filename);
                                return 0;
                        }
-                       strncpy(*(char **)return_val, temp, strlen);
+                       strncpy(*(char **)return_val, temp, len);
                        break;
                case CONFIG_TYPE_BOOL:
                        success = config_lookup_bool(&cfg, path, return_val);
@@ -81,12 +81,12 @@
  *  @param return_val Pointer to the variable where the information should be 
stored
- *  @param strlen Length of the string (if looking up a string).
+ *  @param len Length of the string (if looking up a string).
  *
  *  @return 1 on success; 0 on failure

Other related posts:

  • » [pisa-src] r1449 - trunk/pairing/libconfig_wrapper.c - Thomas Jansen